%global common_description %{expand:
The Trio project's goal is to produce a production-quality, permissively
licensed, async/await-native I/O library for Python.  Like all async libraries,
its main purpose is to help you write programs that do multiple things at the
same time with parallelized I/O.  A web spider that wants to fetch lots of
pages in parallel, a web server that needs to juggle lots of downloads and
websocket connections at the same time, a process supervisor monitoring
multiple subprocesses... that sort of thing.  Compared to other libraries, Trio
attempts to distinguish itself with an obsessive focus on usability and
correctness.  Concurrency is complicated; we try to make it easy to get things
right.}

%bcond_without tests


Name:           python-trio
Version:        0.8.0
Release:        1%{?dist}
Summary:        An async/await-native I/O library for humans and snake people
License:        MIT or ASL 2.0
URL:            https://github.com/python-trio/trio
Source0:        %{pypi_source trio}
BuildArch:      noarch


%description %{common_description}


%package -n python3-trio
Summary:        %{summary}
BuildRequires:  python3-devel
BuildRequires:  python3-setuptools
%if %{with tests}
BuildRequires:  python3-pytest
BuildRequires:  python3-pyOpenSSL
BuildRequires:  python3-trustme
BuildRequires:  python3-attrs
BuildRequires:  python3-sortedcontainers
BuildRequires:  python3-async-generator
BuildRequires:  python3-idna
BuildRequires:  python3-outcome
BuildRequires:  python3-sniffio
%endif
%{?python_provide:%python_provide python3-trio}


%description -n python3-trio %{common_description}


%prep
%autosetup -n trio-%{version}


%build
%py3_build


%install
%py3_install


%check
%if %{with tests}
%pytest --verbose trio/_core/tests
%else
%py3_check_import trio
%endif


%files -n python3-trio
%license LICENSE LICENSE.MIT LICENSE.APACHE2
%doc README.rst
%{python3_sitelib}/trio
%{python3_sitelib}/trio-%{version}-py%{python3_version}.egg-info


%changelog
* Thu Jun 01 2023 Carl George <carl@george.computer> - 0.8.0-1
- Update to version 0.8.0

* Thu Sep 20 2018 Carl George <carl@george.computer> - 0.7.0-1
- Initial package
